/*---------------------------------------------------------------------------*\
  =========                 |
  \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
   \\    /   O peration     |
    \\  /    A nd           | Copyright (C) 1991-2004 OpenCFD Ltd.
     \\/     M anipulation  |
-------------------------------------------------------------------------------
License
    This file is part of OpenFOAM.

    OpenFOAM is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
    Free Software Foundation; either version 2 of the License, or (at your
    option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM; if not, write to the Free Software Foundation,
    Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA

Application
    setGamma

Description
    Set the initial field of gamma for the dam break problem.

\*---------------------------------------------------------------------------*/

#include "fvCFD.H"
#include "OSspecific.H"

#include "cellSet.H"
#include <fstream>

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

int main(int argc, char *argv[])
{

  argList::validArgs.append("fieldName");
  argList::validArgs.append("cellSetName");
  argList::validArgs.append("value");
  
#   include "setRootCase.H"

#   include "createTime.H"
#   include "createMesh.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

  word fieldName(args.args()[3]);
  word cellSetName(args.args()[4]);
  scalar theValue(readScalar(IStringStream(args.args()[5])()));

  Info << "Setting " << fieldName << " on cellSet " << cellSetName << " to " << theValue << endl;

#   include "createFields.H"

  cellSet theCellSet(mesh,cellSetName,IOobject::MUST_READ,IOobject::NO_WRITE);
  
  for(cellSet::iterator cell=theCellSet.begin();cell!=theCellSet.end();cell++)
    theField[cell.key()]=theValue;

  theField.write();
  
  Info<< "End\n" << endl;
  
  return(0);
}


// ************************************************************************* //
